function d = Kolmogorov_Smirnov_distance(f1,f2)
%-------------------------------------------------------------------------
% function d = Kolmogorov_Smirnov_distance(f1,f2)
% 
% Calculation of the dissimilarity of two feature vectors
% 
%
% input:    f1          feature vector of image 1
%           f2          feature vector of image 2
%
% output:   d           dissimilarity between f1 and f2
%-------------------------------------------------------------------------
% Date: 7.12.04
% Name: Barbara Frank

%dissimilarity measure is the Kolmogorov-Smirnov-distance,
%the cumulative histograms of f1 and f2 are compared
%important precondition: f1 and f2 must be marginal histograms

[n1,m1] = size(f1);
[n2,m2] = size(f2);
if (n1==n2 && m1 == m2 )
     maximum1 = 0;
     maximum2 = 0;
     maximum3 = 0;
     sumf1=0;
     sumf2=0;
     for i=1:max(n1,m1)/3
       sumf1=sumf1+f1(i);
       sumf2=sumf2+f2(i);
       maxtemp=abs(sumf1-sumf2);
       if(maxtemp>maximum1)
         maximum1=maxtemp;
       end
     end
     sumf1=0;
     sumf2=0;

     for i=max(n1,m1)/3+1:max(n1,m1)/3*2
       sumf1=sumf1+f1(i);
       sumf2=sumf2+f2(i);
       maxtemp=abs(sumf1-sumf2);
       if(maxtemp>maximum2)
         maximum2=maxtemp;
       end
     end
     sumf1=0;
     sumf2=0;

     for i=max(n1,m1)/3*2+1:max(n1,m1)
       sumf1=sumf1+f1(i);
       sumf2=sumf2+f2(i);
       maxtemp=abs(sumf1-sumf2);
       if(maxtemp>maximum3)
         maximum3=maxtemp;
       end
     end
       d=maximum1+maximum2+maximum3;
%d=maximum1;
else
     d=-1;
end
