function d = L_p_norm(f1,f2,p)
%-------------------------------------------------------------------------
% function d = L_p_norm(f1,f2,p)
%
% Calculation of the Minkowsky form distance of two feature vectors
%
% input:    f1          feature vector of image 1
%           f2          feature vector of image 2
%           p           parameter p for the L_p norm (default:2)
%                       if p greater than 50, the L_infinity norm is calculated
%
% output:   d           L_p-dissimilarity between f1 and f2
%-------------------------------------------------------------------------
% Date: 7.12.04
% Name: Barbara Frank

%dissimilarity measure is the Lp norm

if ( nargin < 3)
        p=2;
end

[n1,m1] = size(f1);
[n2,m2] = size(f2);
if (n1==n2)
   if(p<50)
     sum=0;
     for i=1:n1
        sum=sum+realpow((abs(f1(i)-f2(i))),p);
     end
     d=realpow(sum,1/p);
   else

     max=0;
     for i=1:n1
        maxtemp=abs(f1(i)-f2(i));
        if(maxtemp>max)
           max=maxtemp;
        end
     end
     d=max;
   end
else
 d=-1;
end
