function d = calc_gabor_dissimilarity(search_image,dist_measure,p)
%-------------------------------------------------------------------------
% function d = calc_gabor_dissimilarity(image_name,dist_measure,p)
% 
% Calculation of the most similar images from the db given a reference
% image with gabor features
%
% input:    image_name            reference rgb image (the image name please!!!)
%           dist_measure          dissimilarity function
%                                 'L_p_norm', 
%                                 'Chi_Square' or 
%                                 'Jeffrey_divergence'
%           p                     optional parameter for the Lp-norm
%
% output:   d                     (n x 1) vector for the distance between 
%                                 the feature vector of the colors red green
%                                 and blue of the image and the feature
%                                 vector of each image in the colordb
%                                 sorted in ascending order. In one row the
%                                 values of the absolut difference of the
%                                 features vectors and the number of the
%                                 image of the database that is compared to
%                                 the input image interchange for the
%                                 colors red, green and blue
%-------------------------------------------------------------------------
% Date: 10.12.2004
% Name: Barbara Frank

if(nargin < 3)
     p=2;
end
if(nargin < 2)
     dist_measure='L_p_norm';
end

load('texturdb_gabor');

image_name = strcat('imgdatabase/',strcat(int2str(search_image),'.jpg'));
[m n]=size(texturdb);

%the pictures in this weird database are totally unordered, at least 
%numerically, thus it is not possible to just look up the appropriate feature
%vector of image i in the database at position i or maybe i-1,
%but we have to search the whole database and compare the strings!!!
Bild = 1;
  
for k = 1 : n
  if (strcmp(texturdb(k).img_name,image_name))
     Bild = k;
     break;
  end
end 

fvec1 = texturdb(Bild).GBR;
T=zeros(n,2);

switch dist_measure
  case 'L_p_norm'
   for k = 1 : n
     fvec2 = texturdb(k).GBR;
     T(k,1) = L_p_norm(fvec1,fvec2,p);
     T(k,2) = str2num(texturdb(k).img_name(strfind(texturdb(k).img_name,'/')+1: strfind(texturdb(k).img_name,'.')-1));
   end
  case 'Chi_Square'
   for k = 1 : n
     fvec2 = texturdb(k).GBR;
     T(k,1) = Chi_Square(fvec1,fvec2);
     T(k,2) = str2num(texturdb(k).img_name(strfind(texturdb(k).img_name,'/')+1: strfind(texturdb(k).img_name,'.')-1));
   end
  case 'Jeffrey_divergence'
   for k = 1 : n
     fvec2 = texturdb(k).GBR;
     T(k,1) = Jeffrey_divergence(fvec1,fvec2);
     T(k,2) = str2num(texturdb(k).img_name(strfind(texturdb(k).img_name,'/')+1: strfind(texturdb(k).img_name,'.')-1));
   end
end
T = sortrows(T,2);

d=T(:,1);
