function d = calc_hist_dissimilarity(search_image,dist_measure,p)
%-------------------------------------------------------------------------
% function d = calc_hist_dissimilarity(search_image,dist_measure,p)
% 
% Calculation of the most similar images from the db given a reference
% image
%
% input:    image                 reference rgb image
%           dist_measure          dissimilarity function: one of the following:
%                                 'L_p_norm'
%                                 'Chi_Square' 
%                                 'Jeffrey_divergence' 
%                                 'Histogram_intersection'
%                                 'Kolmogorov_Smirnov_distance'
%                                 'Match_distance'
%                                 'Quadratic_form_distance'
%           p                     optional parameter for the Lp-norm
%
% output:   d                     (n x 1) vector for the distance between 
%                                 the feature vector of the colors red green
%                                 and blue of the image and the feature
%                                 vector of each image in the histogramdb
%                                 sorted in ascending order. In one row the
%                                 values of the absolut difference of the
%                                 features vectors and the number of the
%                                 image of the database that is compared to
%                                 the input image interchange for the
%                                 colors red, green and blue
%-------------------------------------------------------------------------
% Date: 10.12.2004
% Name: Barbara Frank



if(nargin<3)
     p=2;
end
if(nargin<2)
     dist_measure='L_p_norm';
end
if(strcmp(dist_measure,'Kolmogorov_Smirnov_distance')|strcmp(dist_measure,'Match_distance'))
     load('histogramdb.mat');
     [m n] = size(histogramdb)
     f=histogramdb(search_image+1).ftsvec;
else 
     load('histogram3ddb.mat');
     [m n] = size(histogram3ddb);
     f=histogram3ddb(search_image+1).ftsvec;
end

d = zeros(n,1);

switch dist_measure
  case 'L_p_norm'
    for i= 1:n
      f_i = histogram3ddb(i).ftsvec; 
      dist = L_p_norm(f,f_i,p);
      d(i) = dist;
    end

  case 'Chi_Square'
    for i= 1:n
      f_i = histogram3ddb(i).ftsvec; 
      dist = Chi_Square(f,f_i);
      d(i) = dist;
    end
  case 'Jeffrey_divergence'
    for i= 1:n
      f_i = histogram3ddb(i).ftsvec;
      dist = Jeffrey_divergence(f,f_i);
      d(i) = dist;
    end
  case 'Quadratic_form_distance'
    B=load('hist_similar_matrix.mat');
    matti=B.A;
    for i= 1:n
      f_i = histogram3ddb(i).ftsvec;
      dist = Quadratic_form_distance(f,f_i,matti);
      d(i) = dist;
    end
  case 'Histogram_intersection'
    for i= 1:n
      f_i = histogram3ddb(i).ftsvec;
      dist = Histogram_intersection(f,f_i);
      d(i) = dist;
    end
  case 'Kolmogorov_Smirnov_distance'
    for i= 1:n
      f_i = histogramdb(i).ftsvec;
      dist = Kolmogorov_Smirnov_distance(f,f_i);
      d(i) = dist;
    end
  case 'Match_distance'
    for i= 1:n
      f_i = histogramdb(i).ftsvec;
      dist = Match_distance(f,f_i);
      d(i) = dist;
    end
    
end

 
