function d = calc_region_dissimilarity(img,dist_measure,p1,p2,p)
%-------------------------------------------------------------------------
% function d = calc_region_dissimilarity(img,dist_measure,p1,p2,p)
% 
% Calculation of the most similar images from the db given a reference
% image
%
% input:    image              reference rgb image
%           dist_measure       dissimilarity function
%                              either 'L_p_norm', optionally with parameter p
%                              or 'Chi_Square' 
%                              or 'Jeffrey_divergence' 
%                              or 'Histogram_intersection'
%
%           p1                 penalty, applies if query image has less 
%                              regions than other picture
%           p2                 penalty, applies if query image has more
%                              regions than other picture
%           p                  optional parameter for the Lp-norm
%
% output:   d                  (n x 1) vector for the distance between 
%                              the feature vector of the colors red green
%                              and blue of the image and the feature
%                              vector of each image in the colordb
%                              sorted in ascending order. In one row the
%                              values of the absolut difference of the
%                              features vectors and the number of the
%                              image of the database that is compared to
%                              the input image interchange for the
%                              colors red, green and blue
%-------------------------------------------------------------------------
% Date: 10.12.2004
% Name: Barbara Frank

load('hist1000.mat');
%img = str2num(image_name(strfind(image_name,'/')+1: strfind(image_name,'.')-1))
if(nargin<5)
     p=2;
end
if(nargin<2)
     dist_measure='L_p_norm';
     p1=50000;
     p2=50000;
end

[m n] = size(h);

F=h{img+1};
%getRegionFeatures(image);
%F contains j featurevectors for j regions

[ii i] = size(F);
d = zeros(n,1);


switch dist_measure
  case 'L_p_norm'
   for k = 1:n
      F_k=h{k};
      [jj j] = size(F_k);
      D=zeros(max(i,j),max(i,j));
      for Ri=1:i
       for Rj=1:j
        dist=L_p_norm(F{Ri},F_k{Rj},p);
        D(Ri,Rj)=dist;
       end
      end      
     if(i<j)   
      for z=Ri+1:j
        D(z,:)=p1;
      end
     end
     if(j<i)
      for(y=Rj+1:i)
        D(:,y)=p2;
      end
     end
     
      idx=hungarian(D);
      [hh hhh]=size(idx);
     sum=0;
     for x=1:hhh
     sum=sum+D(idx(x),x);
     end
     sum=sum/hhh;
     d(k)=sum;

    end
  case 'Chi_Square'
   for k = 1:n
      F_k=h{k};
      [jj j] = size(F_k);
      D=zeros(max(i,j),max(i,j));
      for Ri=1:i
       for Rj=1:j
        dist=Chi_Square(F{Ri},F_k{Rj});
        D(Ri,Rj)=dist;
       end
      end      
     if(i<j)   
      for z=Ri+1:j
        D(z,:)=p1;
      end
     end
     if(j<i)
      for(y=Rj+1:i)
        D(:,y)=p2;
      end
     end
     
      idx=hungarian(D);
      [hh hhh]=size(idx);
     sum=0;
     for x=1:hhh
     sum=sum+D(idx(x),x);
     end
     sum=sum/hhh;
     d(k)=sum;

    end
  case 'Jeffrey_divergence'
   for k = 1:n
      F_k=h{k};
      [jj j] = size(F_k);
      D=zeros(max(i,j),max(i,j));
      for Ri=1:i
       for Rj=1:j
        dist=Chi_Square(F{Ri},F_k{Rj});
        D(Ri,Rj)=dist;
       end
      end      
     if(i<j)   
      for z=Ri+1:j
        D(z,:)=p1;
      end
     end
     if(j<i)
      for(y=Rj+1:i)
        D(:,y)=p2;
      end
     end
     
      idx=hungarian(D);
      [hh hhh]=size(idx);
     sum=0;
     for x=1:hhh
     sum=sum+D(idx(x),x);
     end
     sum=sum/hhh;
     d(k)=sum;

    end
  case 'Histogram_intersection'
   for k = 1:n
      F_k=h{k};
      [jj j] = size(F_k);
      D=zeros(max(i,j),max(i,j));
      for Ri=1:i
       for Rj=1:j
        dist=Histogram_intersection(F{Ri},F_k{Rj});
        D(Ri,Rj)=dist;
       end
      end      
     if(i<j)   
      for z=Ri+1:j
        D(z,:)=p1;
      end
     end
     if(j<i)
      for(y=Rj+1:i)
        D(:,y)=p2;
      end
     end
     
      idx=hungarian(D);
      [hh hhh]=size(idx);
     sum=0;
     for x=1:hhh
     sum=sum+D(idx(x),x);
     end
     sum=sum/hhh;
     d(k)=sum;

    end

     minel=min(d);
maxel=max(d);
dim=d(img+1);
dind=img+1;
end

