function D = find_sim_pics_ht(search_image,alpha,beta,dist1,dist2,p1,p2)
%-----------------------------------------------------------------------
% function d = find_sim_pics_ht(search_image,alpha,beta,dist1,dist2,p1,p2)
%
% Calculates the order of images similar to the input image
% for this purpose, histogram and texture features are compared
%
% input:        image          the query image
%
%               alpha          weighting factor for the histograms
%               beta           weighting factor for the texture 
%
%               dist1          the dissimilarity measure for the histograms
%                              either 'L_p_norm', optionally with parameter p1 
%                              or 'Chi_Square' 
%                              or 'Jeffrey_divergence' 
%                              or 'Histogram_intersection'
%                              or 'Kolmogorov_Smirnov_distance'
%                              or 'Match_distance'
%                              or 'Quadratic_form_distance'
%
%               dist2          the dissimilarity measure for the texture
%                              either 'L_p_norm', optionally with parameter p2 
%                              or 'Chi_Square' 
%                              or 'Jeffrey_divergence' 
%                              or 'Histogram_intersection'
%                              or 'Kolmogorov_Smirnov_distance'
%                              or 'Match_distance'
%                              or 'Quadratic_form_distance'
%
% output:       D              (n x 2) vector of dissimilarities for all the 
%                              images in the database with the corresponding
%                              image number
%
%                       
%                       
%                       
%                       
%                       
%                       
%
%-----------------------------------------------------------------------
%  Date: 14.12.2004 
%  Author: Barbara Frank

if (nargin < 7)
  p1=2;
  p2=2;
end
if (nargin < 5)
     dist1='L_p_norm';
     dist2='L_p_norm';
end
if (nargin < 3)
     alpha=1/2;
     beta=1/2;

end
search_image
%image=imread(image_name);
if(abs(alpha)>0)
     d1=calc_hist_dissimilarity(search_image,dist1,p1);
else d1=zeros(1000,1);
end

if(abs(beta)> 0)
     d2=calc_gabor_dissimilarity(search_image,dist2,p2);
else d2=zeros(1000,1);
end

d= alpha .* d1 + beta .* d2;

[d,indexR] = sort(d);

D = [d,indexR-1];
