function D = find_sim_regions(img,query_type,dist,p)
%-----------------------------------------------------------------------
% function D = find_sim_regions(img,query_type,dist,p)
%
% Calculates the order of images similar to the input image
% for this purpose, moment and texture features are compared
%
% input:      img             the number of the query image
%
%             query_type      type of image search
%                             'part_of', 'similarity' or 'contains'
%
%             dist            the dissimilarity measure for the histograms
%                             either 'L_p_norm', optionally with parameter p1 
%                             or 'Chi_Square' 
%                             or 'Jeffrey_divergence' 
%                             or 'Histogram_intersection'
%
% output:     D               (n x 2) vector of dissimilarities for all the 
%                             images in the database with the corresponding
%                             image number
%
%                       
%                       
%                       
%                       
%                       
%                       
%
%-----------------------------------------------------------------------
%  Date: 14.12.2004 
%  Author: Barbara Frank

if (nargin < 4)
  p=2;
end

if (nargin < 3)
     dist='Jeffrey_divergence';
end
if (nargin < 2)
     query_type='similarity';
end

%image=imread(image_name);

switch query_type
  case 'contains'
    p1=0;
    p2=70000;

  case 'similarity'
    p1=10000;
    p2=10000;
  case 'part_of'
    p1=70000;
    p2=0;
end
d=calc_region_dissimilarity(img,dist,p1,p2,p);

[d,indexR] = sort(d);

D = [d,indexR-1];
