function val = plot_sim_pics(search_image,dist,p)
%-----------------------------------------------------------------------
% function  val = plot_sim_pics_ht(search_image,alpha,beta,dist1,dist2,p1,p2)
%
% Search for similar pictures in the database using histograms and texture
%
% input:    search_image    the picture for which we want to find similar ones
%
%           alpha           weighting factor for the histogram dissimilarity
%           beta            weighting factor for the texture dissimilarity
%
%           dist1           the dissimilarity measure for the histograms
%                           either 'L_p_norm', optionally with parameter p1 
%                           or 'Chi_Square' 
%                           or 'Jeffrey_divergence' 
%                           or 'Histogram_intersection'
%                           or 'Kolmogorov_Smirnov_distance'
%                           or 'Match_distance'
%                           or 'Quadratic_form_distance'
%
%           dist2           the dissimilarity measure for the texture
%                           either 'L_p_norm', optionally with parameter p2 
%                           or 'Chi_Square' 
%                           or 'Jeffrey_divergence' 
%                           or 'Histogram_intersection'
%                           or 'Kolmogorov_Smirnov_distance'
%                           or 'Match_distance'
%
%
%
% output:   val             the dissimilarity vector
%                           
%
%-----------------------------------------------------------------------
%  Date: 10.12.2004 
%  Author: Barbara Frank

%
%


if (nargin < 3)
  p=2;
end
if (nargin < 2)
     dist='L_p_norm';
end


image = imread(strcat(int2str(search_image),'.jpg'));
tic
d = calc_hist_dissimilarity(search_image,dist,p);
toc
[d,indexR] = sort(d);

similar_vector = [d,indexR-1];

size(similar_vector);

query_imgs = ev_query_images;
if find(similar_vector(1,2)==query_imgs)
 rank_table = similar_vector(:,2);
 query_id = similar_vector(1,2);
 R = ev_img_query_from_ids(query_id,rank_table);
 R1 = ev_mvalues(R);
 ev_plot_pr(R1);
end


figure;
hold on;
%picture with the  highest similarity value in the similarity vector
k = similar_vector(1,2);
j = int2str(k);
image_name = strcat(j,'.jpg');
subplot(5,3,2);
imshow(image_name);
title('query image')
for i=1:12
  k = similar_vector(i,2);
  j = int2str(k);
  image_name = strcat(j,'.jpg');
  subplot(5,3,3+i);
  imshow(image_name);
%  title(strcat(image_name,strcat(': ',num2str(similar_vector(i,1)))));
end
hold off;

val=similar_vector;
